Rev 5810: Merge config-options into config-editor-option in file:///home/vila/src/bzr/experimental/config/
Vincent Ladeuil
v.ladeuil+lp at free.fr
Tue May 31 15:47:16 UTC 2011
At file:///home/vila/src/bzr/experimental/config/
------------------------------------------------------------
revno: 5810 [merge]
revision-id: v.ladeuil+lp at free.fr-20110531154715-0tpvr0l75qp37vi4
parent: v.ladeuil+lp at free.fr-20110531082530-c7h5g3dl6tiieemi
parent: v.ladeuil+lp at free.fr-20110531154715-j54pi6szv7irmyjz
committer: Vincent Ladeuil <v.ladeuil+lp at free.fr>
branch nick: config-editor-option
timestamp: Tue 2011-05-31 17:47:15 +0200
message:
Merge config-options into config-editor-option
modified:
bzrlib/tests/test_config.py testconfig.py-20051011041908-742d0c15d8d8c8eb
-------------- next part --------------
=== modified file 'bzrlib/tests/test_config.py'
--- a/bzrlib/tests/test_config.py 2011-05-30 14:56:00 +0000
+++ b/bzrlib/tests/test_config.py 2011-05-31 15:47:15 +0000
@@ -94,15 +94,15 @@
:param server_class: The server associated with the ``transport_class``
above.
- Either both or none of ``transport_class`` and ``server_class`` should be
- specified.
+ Either both or neither of ``transport_class`` and ``server_class`` should
+ be specified.
"""
if transport_class is not None and server_class is not None:
test.transport_class = transport_class
test.transport_server = server_class
elif not (transport_class is None and server_class is None):
raise AssertionError('Specify both ``transport_class`` and '
- '``server_class`` or none of them')
+ '``server_class`` or neither of them')
if getattr(test, 'backing_branch', None) is None:
# First call, let's build the branch on disk
test.backing_branch = test.make_branch(relpath)
@@ -708,11 +708,11 @@
def test_default_is_True(self):
self.config = self.get_config(True)
self.assertExpandIs(True)
-
+
def test_default_is_False(self):
self.config = self.get_config(False)
self.assertExpandIs(False)
-
+
class TestIniConfigOptionExpansion(tests.TestCase):
"""Test option expansion from the IniConfig level.
More information about the bazaar-commits
mailing list